function output = get(H,fieldname)
%GET Get smhank object fields.
%
%   GET(H) displays all field names and their current values
%   for smhank object H.
%
%   V = GET(H) returns a structure, V, where each field name is
%   the name of a field of H and each field contains the value
%   of the corresponding field of H.
%
%   V = GET(H,'FieldName') returns the value, V, of the
%   specified field, FieldName, for smhank object H.
%   If FieldName is a 1-by-N or N-by-1 cell array of strings
%   containing field names, GET returns a 1-by-N cell array
%   of values.
%
%   Example:
%       H = smhank
%       get(H, {'dim1','dim2'})
%       out = get(H, 'h')
%       get(H)
%
%   See also SMHANK.

%  Giuseppe Rodriguez, University of Cagliari, Italy
%       Email: rodriguez@unica.it
%
%  Last revised Dec 11, 2016

if (nargout == 0) && (nargin == 1)
% Case "get(H)"
	disp(' ');
	if issparse(H.h),  s = ' (sparse) ';  else  s = ' ';  end
	disp([inputname(1),' is a smhank',s,'object with fields:'])
	disp(struct(H))
elseif (nargout == 1) && (nargin == 1)
% Case "V=get(H)"
	output = struct(H);
elseif (nargin == 2) && ~iscell(fieldname)
% Case "get(H,'PN')"
	switch fieldname
	case 'h'
		val = H.h;
	case 'dim1'
		val = H.dim1;
	case 'dim2'
		val = H.dim2;
	case 'cev'
		val = H.cev;
	otherwise
		error(['There is no ''',fieldname, ...
			''' field for smhank objects.'])
	end
	output = val;
else
% Case "get(H,{'PN',...})"
	% get field names
	len = length(fieldname);
	output = cell(1,len);
	for lcv=1:len
		field = char(fieldname(lcv));
		switch field
		case 'h'
			val = H.h;
		case 'dim1'
			val = H.dim1;
		case 'dim2'
			val = H.dim2;
		case 'cev'
			val = H.cev;
		otherwise
			error(['There is no ''',field, ...
				''' field for smhank objects.'])
		end
		output{1,lcv} = val;
	end
end

