function [H,C] = khprem(H)
%HKPREM Toeplitz premultiplication.
%
%   S = HKPREM(H) returns a smhank object S representing the
%   same Hankel matrix H with, in addition, the eigenvalues
%   of the circulant matrix C in which H is embedded.
%
%   [S,C] = HKPREM(H) returns S as in the previous case, but
%   also the circulant matrix C as a smcirc object.
%
%   Premultiplication speeds up multiplication of a smhank
%   matrix by another array.
%
%   See also SMHANK.

%  Giuseppe Rodriguez, University of Cagliari, Italy
%       Email: rodriguez@unica.it
%
%  Last revised August 11, 2011

if ~isempty(H)
	% Get the dimension of the circulant matrix for embedding H.
	immfun = smtconfig('tpemb');
	N = immfun(H.dim1,H.dim2);
	C = smcirc([H.h(H.dim2:H.dim1+H.dim2-1);zeros(N-H.dim1-H.dim2+1,1); ...
		H.h(1:H.dim2-1)]);
	v = eig(C);
	if ~isempty(H.cev)
		warning('SMT:smhank:ExistingCevField', ...
			'The ''cev'' field of the argument is not empty.')
		if (size(v,1) ~= size(H.cev,1))
		% We should never end up here.
			error('The dimension of the ''cev'' field of the argument is wrong.')
		end
	else
		H.cev = v;
	end
else
	C = smcirc;
end

