function is = isa(H,str)
%ISA True if object is a given class.
%
%   ISA(OBJ,'class_name') returns 1 if OBJ is of the class 
%   'class_name' and 0 otherwise.
%
%   Example:
%      H = smhank;
%      isa(H,'smhank') 		returns 1
%      isa(H,'float')		returns 1
%      isa(H,'double')		returns 1 if H.h is 'double'
%      isa(H,'single')		returns 1 if H.h is 'single'
%      isa(H,'other_class')	returns 0
%
%   See also SMTVALID, SMHANK/SMTVALID.

%
%  Giuseppe Rodriguez, University of Cagliari, Italy
%       Email: rodriguez@unica.it
%
%  Last revised May 22, 2011

if nargin<2
	error('Not enough input arguments.')
end

if strcmp(str,'smhank')
	is = 1;
elseif strcmp(str,'double') && isa(H.h,'double')
% weird, but necessary for running pcg correctly.
	is = 1;
elseif strcmp(str,'single') && isa(H.h,'single')
% weird, but necessary for running pcg correctly.
	is = 1;
elseif strcmp(str,'float')
% added for compatibility between Matlab 6.x and 7.x.
	is = 1;
else
	is = 0;
end

