function y = norm(H,p)
%NORM   Matrix or vector norm.
%
%   For smtoep objects...
%     NORM(H,1) is the 1-norm of H, the largest column sum,
%                     = max(sum(abs(H))).
%     NORM(H,inf) is the infinity norm of H, the largest row sum,
%                     = max(sum(abs(H'))).
%     NORM(H,'fro') is the Frobenius norm, sqrt(sum(diag(H'*H))).
%     NORM(H,2) is not implemented yet.
%     NORM(H,P) is available for H only if P is 1, inf or 'fro'.

%  Giuseppe Rodriguez, University of Cagliari, Italy
%       Email: rodriguez@unica.it
%
%  Last revised April 17, 2009

if nargin < 2,
	error('You must supply P = 1, inf or ''fro''.')
end

switch p
   case 2
	error('Not yet implemented, use norm(full(H),2) instead.')
   case 1
   	y = max(sum(abs(H)));
   case {inf,'inf'}
   	y = max(sum(abs(H')));
   case 'fro'
   	k = min([H.dim1 H.dim2]);
	y = sqrt([1:k k*ones(1,abs(H.dim1-H.dim2)) k-1:-1:1] * abs(H.h).^2);
   otherwise
   	error('The only matrix norms available are 1, inf, and ''fro''.')
end
