function varargout = size(H,k)
%SIZE Size of a smhank matrix.
%
%    D = SIZE(H), for M-by-N smhank matrix H, returns the two-element
%    row vector D = [M,N] containing the number of rows and columns 
%    in the matrix.
%
%    [M,N] = SIZE(H) returns the number of rows and columns in separate
%    output variables.
%
%    M = SIZE(H,DIM) returns the length of the dimension specified by
%    the scalar DIM. For example, SIZE(H,1) returns the number of rows.
%
%    See also SMHANK/LENGTH.

%  Giuseppe Rodriguez, University of Cagliari, Italy
%       Email: rodriguez@unica.it
%
%  Last revised April 18, 2009

% Determine the number of output arguments.
numOut = nargout;

if (numOut == 0)
% If zero output arguments, modify numOut to 1 so that the expression below
% evaluates without error.
	numOut = 1;
end

if nargin == 1
	if numOut == 1
		[varargout{1}] = [H.dim1 H.dim2];
	else
		[varargout{1}] = H.dim1;
		[varargout{2}] = H.dim2;
	end
else
	if ~isnumeric(k) ||  max(size(k)~=1)
		error('The second argument is not a number.')
	else
		switch k
		case 1
			varargout{1} = H.dim1;
		case 2
			varargout{1} = H.dim2;
		otherwise
			varargout{1} = 1;
		end
	end
end
