function S = sum(H,dim)
%SUM    Sum of elements.
%
%   S = SUM(H,dim) takes the sums along the dimension of H
%   specified by scalar dim.
%   For smhank row or column vectors, SUM(H) is the sum of 
%   the elements of H.
%   For matrices, SUM(H) or SUM(H,1) is a row vector of column 
%   sums and SUM(H,2) is a column vector of row sums.
%
%   See also SMHANK/PROD.
 
%  Giuseppe Rodriguez, University of Cagliari, Italy
%       Email: rodriguez@unica.it
%
%  Last revised June 9, 2006

if nargin == 1 && isempty(H.h)
    % H is empty
    S = 0;
elseif nargin == 1 && any(size(H) == 1)
    % If one of the dimensions of H is 1
    S = sum(H.h);
elseif nargin == 1 || dim == 1
    % If no dim parameter or dim equal to 1
    S = ones(1,H.dim1)*H;
elseif dim == 2
    % If dim equal to 2
    S = H*ones(H.dim2,1);
elseif dim <= 0
    error('Dimension argument must be a positive integer scalar.')
else
    S = H;
end
